tiled.queries.In
================

.. currentmodule:: tiled.queries

.. autoclass:: In

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~In.__init__
      ~In.decode
      ~In.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~In.key
      ~In.value
   
   